<?php

namespace TheBugs\Email;

use Symfony\Component\Mailer\{ Mailer, Transport };
use Symfony\Component\Mime\Email;

class SymfonyMailer implements MailerInterface
{
    use EmailInfoTrait;

    public Mailer $mailer;

    public function __construct(EmailConfiguration $configuration) {
        $this->emailConfiguration = $configuration;
        $this->mailer = new Mailer(Transport::fromDsn(spritf("smtp://%s:%s@%s:%d", $this->emailConfiguration->smtpUsername, $this->emailConfiguration->smtpPassword, $this->emailConfiguration->smtpHost, $this->emailConfiguration->smtpPort)));
    }

    public function send(string $subject, string $message, bool $html = true) : bool
    {
        $email = ( new Email() )
            ->subject($subject)
            ->from($this->from)
            ->to(...( (array)$this->to ))
            ->cc(...($this->cc ?? []))
            ->bcc(...($this->bcc ?? []));

        if ($html) {
            $email->html($message);
        }
        else {
            $email->text($message);
        }

        foreach ($this->attachments as $path) {
            $email->attachFromPath($path);
        }

        $this->attachments = [];

        return $this->mailer->send($email);
    }

    public function attach(mixed $attachment) : self
    {
        $this->attachments[] = $attachment;

        return $this;
    }
}